#define INITGUID
#include <ole2.h>
#include "CoMathn.h"
#include "UUID.h"

static DWORD g_dwServerCount = 0;

class CoMathClassFactory : public IClassFactory {

public:
   CoMathClassFactory();

   STDMETHODIMP_(DWORD) AddRef();
   STDMETHODIMP_(DWORD) Release();
   STDMETHODIMP QueryInterface(REFIID riid, LPVOID FAR *ppv);

   STDMETHODIMP CreateInstance(IUnknown * pUnkOuter,
                               REFIID riid,  
                               VOID ** ppvObject);
   STDMETHODIMP LockServer(BOOL fLock);

private:
   DWORD m_dwRefCount;
};

static CoMathClassFactory coMathCF;


CoMath::CoMath() {
   m_dwRefCount = 0;
   m_persistObj.m_pParent = this;
   m_mathObj.m_pParent = this;
   g_dwServerCount++;
}

CoMath::~CoMath() {
   g_dwServerCount--;
}

DWORD CoMath::AddRef(void) {
  return ++m_dwRefCount;
}

DWORD CoMath::Release(void) { 
  DWORD dwResult = --m_dwRefCount;
  if (!dwResult) 
    delete this;
  return dwResult;
}

HRESULT CoMath::QueryInterface(REFIID iid, void** ppvObj) {
    if (iid == IID_IUnknown) {
        *ppvObj = (LPUNKNOWN)this;
        AddRef();
        return NOERROR;
    } else
    if (iid == IID_IPersist)
    {
        *ppvObj = (LPPERSIST)&m_persistObj;
        AddRef();
        return NOERROR;

    }
    else if (iid == IID_IMath)
    {
        *ppvObj = (IMath *)&m_mathObj;
        AddRef();
        return NOERROR;
    }
    return ResultFromScode(E_NOINTERFACE);
}


ULONG CoMath::PersistObj::AddRef()  { 
    return m_pParent->AddRef(); 
}

ULONG CoMath::PersistObj::Release() 
{ 
    return m_pParent->Release(); 
}

HRESULT CoMath::PersistObj::QueryInterface(
    REFIID iid, void** ppvObj) { 
    return m_pParent->QueryInterface(iid, ppvObj); 
}


ULONG CoMath::MathObj::AddRef() 
{ 
    return m_pParent->AddRef(); 
}

ULONG CoMath::MathObj::Release() 
{ 
    return m_pParent->Release(); 
}

HRESULT CoMath::MathObj::QueryInterface(
    REFIID iid, void** ppvObj) 
{ 
    return m_pParent->QueryInterface(iid, ppvObj); 
}

HRESULT CoMath::PersistObj::GetClassID(LPCLSID pclsid) {
  *pclsid = CLSID_CoMath;
  return NOERROR;
}

HRESULT CoMath::MathObj::Add(INT n1, INT n2, LPLONG lpResult) {
   *lpResult = n1 + n2;
   return NOERROR;
}

HRESULT CoMath::MathObj::Subtract(INT n1, INT n2, LPLONG lpResult) {

   *lpResult = n1 - n2;
   return NOERROR;
}

CoMathClassFactory::CoMathClassFactory() {
   m_dwRefCount = 0;
}

DWORD CoMathClassFactory::AddRef(void) {
  return ++m_dwRefCount;
}

DWORD CoMathClassFactory::Release(void) { 
  DWORD dwResult = --m_dwRefCount;

  return dwResult;
}

HRESULT CoMathClassFactory::QueryInterface(REFIID riid, LPVOID FAR *ppv)
{
  *ppv = 0;

  // Test for each interface here...
  if (riid == IID_IClassFactory)
    *ppv = LPCLASSFACTORY(this);
  else if (riid == IID_IUnknown)
    *ppv = LPUNKNOWN(this);

  // If the Interface was available, AddRef on the way out
  if (*ppv) {
    LPUNKNOWN(*ppv)->AddRef();
    return NOERROR;
  }
  
  // Otherwise return the "No interface" error 
  return ResultFromScode(E_NOINTERFACE);
}

HRESULT CoMathClassFactory::CreateInstance(IUnknown * pUnkOuter,
                                           REFIID riid,  
                                           VOID ** ppvObject) {

   HRESULT hr = ResultFromScode(E_OUTOFMEMORY);

   CoMath *pCoMath = NULL;

   pCoMath = new CoMath;

   hr = pCoMath->QueryInterface(riid, ppvObject);

   if(FAILED(hr))
      delete pCoMath;
   
   return hr;
}

HRESULT CoMathClassFactory::LockServer(BOOL fLock) {
   if(fLock)
      g_dwServerCount++;
   else
      g_dwServerCount--;

   return NOERROR;
};


STDAPI 
DllCanUnloadNow() {
   if(g_dwServerCount > 0)
      return S_FALSE;
   else
      return S_OK;
}

STDAPI
DllGetClassObject(REFCLSID rclsid, REFIID riid, LPVOID FAR*ppv) {

   if (IsEqualCLSID(rclsid, CLSID_CoMath))
      return coMathCF.QueryInterface(riid, ppv);
   else
      return ResultFromScode(CLASS_E_CLASSNOTAVAILABLE); 
}

